;****************************************************************************
;                                                                           *
; Shelly-GUI Install-Script V1.0                                            *
;                                                                           *
; Written by Daniel Aregger                                                 *
;                                                                           *
;****************************************************************************


(TRANSCRIPT
(CAT  "                Shelly-GUI-Install-Logfile\n"
      "                --------------------------\n"
      "                written by Daniel Aregger\n"
      " \n"
      "Shelly-GUI-Install-Script by Daniel Aregger\n"
 )
)

(COMPLETE 0)
(SET ShellyGUI_Version "v1.01")
(SET @default-dest "FSG:")


;=============================================================================

;*** Check OS version

  (IF (= @pretend 0)
    (
      (SET os_ver (/ (GETVERSION) $0000FFFF))
      (IF (< os_ver 37)
         (ABORT "\nF.S.G. requires Kickstart/Workbench 2.04 or higher!\n")
      )
    )
  )


;*** Target

  (UNTIL (= path 2)
    (SET target
      (ASKDIR
        (PROMPT "\nOn which drive/directory should the F.S.G. directory be installed?\n")
        (HELP @askdir-help)
        (DEFAULT @default-dest)
      )
    )
    (SET path
      (EXISTS target (noreq))
    )
  )
  (SET @DEFAULT-DEST target)
  (WORKING "\nInstaller is working..\n")

  (COMPLETE 10)


;*** Update or not ?

  (SET update 
    (EXISTS (tackon target "FSG") (noreq))
  )


;*** Language

  (SET language
    (ASKOPTIONS
      (PROMPT "\nChoose your language (docs)!\n")
      (CHOICES "German" "English")
      (HELP @askoptions-help)
      (DEFAULT 0)
    ) 
  )
 
  (COMPLETE 20)


;*** Kind of Icon

  (SET iconkind
    (ASKCHOICE 
       (CHOICES "Magic-WB Icons" "Normal Icons")
       (PROMPT "\nWhich kind of icons do you want to have installed?\n")
       (HELP @askchoice-help)
       (DEFAULT 1)
    )
  )

  (COMPLETE 30)


;*** Creating directories

  (WORKING "\nCreating directories..\n")
  (IF (= update 0)
    (
      (MAKEDIR (tackon target "FSG")
        (INFOS)     
      )      
      (MAKEDIR (tackon target "FSG/ARexx")
        (INFOS)
      )
      (MAKEDIR (tackon target "FSG/Docs")
        (INFOS)
      )        
    ) 
  )
  (IF (= update 0)
    (
      (SET target (CAT target "/FSG"))
    )
  )

  (COMPLETE 40)


;*** Copying files (ENVARC: & ARexx)

  (WORKING "\nCopying files..\n")
  (COPYFILES
    (SOURCE "ARexx/RealMacro.fsg")
    (DEST
      (TACKON target "Arexx")
    )
    (INFOS)
  )
  (COPYFILES
    (SOURCE "ENVARC/FSG.config")
    (DEST "ENVARC:")
    (INFOS)
  )

  (COMPLETE 50)


;*** Copying Docs

  (WORKING "\nCopying docs..\n")
  (if (<> 0 (BITAND language 2))
    (
      (COPYFILES    
        (SOURCE "Docs/FSG.doc")
        (DEST
          (TACKON target "Docs")
        )
        (INFOS)
      )
      (COPYFILES
        (SOURCE "Docs/FSG_english.guide")
        (DEST
          (TACKON target "Docs")
        )
        (INFOS)
      )
      (IF (= iconkind 0)
        (
          (COPYFILES
            (SOURCE "Docs/FSG_magic.dok.info")
            (DEST (tackon target "Docs"))
          )
          (COPYFILES
            (SOURCE "Docs/FSG_magic.guide.info")
            (DEST (tackon target "Docs"))
          )
          (DELETE (tackon target "Docs/FSG_english.guide.info"))
          (DELETE (tackon target "Docs/FSG.doc.info"))
          (RENAME (tackon target "Docs/FSG_magic.guide.info")
                  (tackon target "Docs/FSG_english.guide.info")
          )
          (RENAME (tackon target "Docs/FSG_magic.dok.info")
                  (tackon target "Docs/FSG.doc.info")
          )
        )
      )
    )
  )
  (IF (<> 0 (BITAND language 1))
    (
      (COPYFILES
        (SOURCE "Docs/FSG.dok")
        (DEST
          (TACKON target "Docs")
        )
        (INFOS)
      )
      (COPYFILES
        (SOURCE "Docs/FSG_deutsch.guide")
        (DEST
          (TACKON target "Docs")
        )
        (INFOS)
      )
      (IF (= iconkind 0)
        (
          (COPYFILES
            (SOURCE "Docs/FSG_magic.dok.info")
            (DEST (tackon target "Docs"))
          )
          (COPYFILES
            (SOURCE "Docs/FSG_magic.guide.info")
            (DEST (tackon target "Docs"))
          )
          (DELETE (tackon target "Docs/FSG_deutsch.guide.info"))
          (DELETE (tackon target "Docs/FSG.dok.info"))
          (RENAME (tackon target "Docs/FSG_magic.guide.info")
                  (tackon target "Docs/FSG_deutsch.guide.info")
          )
          (RENAME (tackon target "Docs/FSG_magic.dok.info")
                  (tackon target "Docs/FSG.dok.info")
          )
        )
      )
    )
  )

  (COMPLETE 80)


;*** Copying executable

  (WORKING "\nCopying executable..\n")
  (COPYFILES
    (SOURCE "FSG")
    (DEST target)
    (INFOS)
  )  


;*** Installing Magic-WB Icon for the executable

  (WORKING "\nInstalling Magic-WB icons..\n")
  (IF (= iconkind 0)
    (
      (COPYFILES
        (SOURCE "FSG_magic.info")
        (DEST target)
      )
      (DELETE (tackon target "FSG.info"))
      (RENAME (tackon target "FSG_magic.info")
              (tackon target "FSG.info")
      )
    )
  )

  (COMPLETE 100)
